# Random-Genetic-Forest

The Random-Genetic Forest(RGF) is a variation of the original Random Forest machine learning algorithm. The RGF algorithm uses genetic algorithms to potential optimize accuracy and/or create non-parametric learning models. This implementation is a Spark module that allows for use in Big Data problems. The RGF Python module consumes datasets using Pyspark dataframes and creates RGF models. 
